pyxmpp.cache

Package pyxmpp :: Module cache |
[hide private]

# Module cache

source code

Caching proxy for Jabber/XMPP objects.

This package provides facilities to retrieve and transparently cache cachable objects like Service Discovery responses or e.g. client version informations.

Classes | [hide private]
| CacheItem An item in a cache.
| CacheFetcher Base class for cache object fetchers -- classes responsible for retrieving objects from network.
| Cache Caching proxy for object retrieval and caching.
| CacheSuite Caching proxy for object retrieval and caching.

Variables | [hide private]
| __revision__ = ``'``$Id: cache.py 714 2010-04-05 10:20:10Z jajcus $``'``
| _state_values = ``{``'``fresh``'``:` 1`,` `'``new``'``:` 0`,` `'``old``'``:` 2`,` `'``purged``'``:` 4`,` `...``
| _hour = `datetime.timedelta(0, 3600)`
| __package__ = ``'``pyxmpp``'``

Imports: threading, datetime, timedelta

Variables Details | [hide private]

  ### _state_values Value:
      {'fresh': 1, 'new': 0, 'old': 2, 'purged': 4, 'stale': 3}